@@ -1,6 +1,6 @@
 import clr
 import os
-from category import categories
+from aacommpy.category import categories
 
 path = os.path.join(os.path.dirname(__file__), 'AAComm.dll')
 clr.AddReference(path)
