@@ -2,11 +2,12 @@ categories = [
     {"from": "AAComm", "name": "CommAPI", "enable": True},
     {"from": "AAComm", "name": "Shared", "enable": True},
     {"from": "AAComm", "name": "Services", "enable": True},
-    {"from": "AAComm", "name": "CommAPIWrapper", "enable": True}, #example of no import
+    {"from": "AAComm", "name": "CommAPIWrapper", "enable": True},
 ]
 SharedCategories = [
     {"from": "AAComm.Shared", "name": "ChannelType", "enable": True},
     {"from": "AAComm.Shared", "name": "ConnectResult", "enable": True},
+    {"from": "AAComm.Shared", "name": "ProductTypes", "enable": True},
 ]
 Servicescategories = [
     {"from": "AAComm.Services", "name": "ConnectionData", "enable": True},
