@@ -6,7 +6,7 @@ import subprocess
 import shutil
 import time
 from aacommpy.nugetmanagement import download_nuget, nuget_version, update_nuget, dotnetfw, check_dotnet_versions
-from settings import NET_FRAMEWORK_CHOICES
+from aacommpy.settings import NET_FRAMEWORK_CHOICES
 
 
 entry_points = {
