@@ -25,8 +25,17 @@ def download_nuget(version: str = "", update: bool = False) -> None:
             dest_dir = os.path.dirname(__file__)
             shutil.copy2(os.path.join(source_dir, 'AACommServer.exe'), dest_dir)
             shutil.copy2(os.path.join(source_dir, 'AACommServerAPI.dll'), dest_dir)
-            source_dir2 = os.path.join(os.path.dirname(nuget_path), f'Agito.AAComm.{new_version}/lib/net5.0')
+            source_dir2 = os.path.join(os.path.dirname(nuget_path), f'Agito.AAComm.{new_version}/lib/net40')
             shutil.copy2(os.path.join(source_dir2, 'AAComm.dll'), dest_dir)
+            # search for the YamlDotNet version
+            for yaml_dirname in os.listdir(os.path.dirname(nuget_path)):
+                if yaml_dirname.startswith('YamlDotNet.') and os.path.isdir(os.path.join(os.path.dirname(nuget_path), yaml_dirname)):
+                    yaml_version = yaml_dirname.split('.')[1:]
+                    yaml_version = '.'.join(yaml_version)
+                    yaml_source_dir = os.path.join(os.path.dirname(nuget_path), f'YamlDotNet.{yaml_version}/lib/net45')
+                    shutil.copy2(os.path.join(yaml_source_dir, 'YamlDotNet.dll'), dest_dir)
+                    shutil.copy2(os.path.join(yaml_source_dir, 'YamlDotNet.xml'), dest_dir)
+                    break 
             break
     return None
 def nuget_version() -> str:
